@@ -158,6 +158,18 @@ class IsSpace(Criteria):
             return False
 
 
+class IsNestSpace(Criteria):
+    def __init__(self, symbols: dict):
+        super(IsNestSpace, self).__init__('IsNestSpace', symbols)
+        self.pattern = re.compile('\s')
+
+    def accept(self, state: StrSequence) -> bool:
+        if self.pattern.match(state.next_value):
+            return True
+        else:
+            return False
+
+
 class IsNextWithSpace(Criteria):
     def __init__(self, symbols: dict):
         super(IsNextWithSpace, self).__init__('IsNextWithSpace', symbols)
@@ -223,10 +235,17 @@ class IsLeftQuotaZH(SpecialCondition):
 class IsLeftQuotaEn(SpecialCondition):
     def __init__(self, SYMBOLS: dict):
         super(IsLeftQuotaEn, self).__init__('IsListQuota', SYMBOLS)
+        self.blank = re.compile('\s')
 
     def accept(self, state: StrSequence) -> bool:
-        if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 != 0 or self.symbols[
-            'quotation_left'].match(state.current_value):
+        # if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 != 0 or self.symbols[
+        #     'quotation_left'].match(state.current_value):
+        #     # state.v_pointer = max(0, state.v_pointer - 1)
+        #     return True
+
+        if self.symbols['quotation_en'].match(state.current_value) and (not self.blank.match(state.next_value)) or \
+                self.symbols[
+                    'quotation_left'].match(state.current_value):
             # state.v_pointer = max(0, state.v_pointer - 1)
             return True
         return False
@@ -235,11 +254,17 @@ class IsLeftQuotaEn(SpecialCondition):
 class IsRightQuotaEn(SpecialCondition):
     def __init__(self, SYMBOLS: dict):
         super(IsRightQuotaEn, self).__init__('SpecialCondition', SYMBOLS)
+        self.blank = re.compile('\s')
 
     def accept(self, state: StrSequence) -> bool:
         if self.symbols['quotation_en'].match(state.current_value) and state.quota_en % 2 == 0 or self.symbols[
             'quotation_right'].match(state.current_value):
             return True
+
+        if self.symbols['quotation_en'].match(state.current_value) and (not self.blank.match(state.pre_value)) and state.v_pointer > 0 or \
+                self.symbols['quotation_right'].match(state.current_value):
+            # state.v_pointer = max(0, state.v_pointer - 1)
+            return True
         return False
 
 
