@@ -16,7 +16,7 @@ SYMBOLS = {
     'comma': re.compile('([,，;])'),
     'end_symbols': re.compile('([?\!…;？！。])'),
     'en_dot': re.compile('\.'),
-    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\){\)\'\s])')
+    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\){\)\s])')
 }
 
 
@@ -32,5 +32,5 @@ SYMBOLS_EN = {
     'comma': re.compile('([,，;])'),
     'end_symbols': re.compile('([?\!…;？！。])'),
     'en_dot': re.compile('\.'),
-    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\){\)\'\s])')
+    'all_symbols': re.compile('([\]\(【\?】。,！[”，\!\.「<>？"（“…《）}》」;:：\){\)\s])')
 }
