@@ -101,7 +101,7 @@ def long_cuter_en(**kwargs):
                 edges.is_book_close,
                 edges.is_quote_close],
                 'args': all,
-                'node': nodes.cut_pre_idx},  # do_cut},
+                'node': nodes.do_cut},  # do_cut},
 
             {'edge': None,
              'node': nodes.init}
